//---------------------------------------------------------------------------
#include <vcl.h>
#pragma hdrstop
USERES("InstallMgr.res");
USEFORM("MainFrm.cpp", MainForm);
USELIB("..\BibleCS\swordlib.lib");
USEFORM("StatusFrm.cpp", StatusForm);
USEFORM("RemoteMntFrm.cpp", RemoteMntForm);
USEFORM("InfoFrm.cpp", InfoForm);
USEFORM("cipherfrm.cpp", CipherForm);
//---------------------------------------------------------------------------
WINAPI WinMain(HINSTANCE, HINSTANCE, LPSTR, int)
{
	try
	{
		Application->Initialize();
		Application->Title = "Install Manager";
		Application->CreateForm(__classid(TMainForm), &MainForm);
		Application->CreateForm(__classid(TStatusForm), &StatusForm);
		Application->CreateForm(__classid(TRemoteMntForm), &RemoteMntForm);
		Application->CreateForm(__classid(TInfoForm), &InfoForm);
		Application->CreateForm(__classid(TCipherForm), &CipherForm);
		Application->Run();
	}
	catch (Exception &exception)
	{
		Application->ShowException(&exception);
	}
	return 0;
}
//---------------------------------------------------------------------------
